@@ -1,3 +1,3 @@
 lib_path = File.expand_path(File.dirname(__FILE__) + "/../../lib")
 $LOAD_PATH.unshift lib_path unless $LOAD_PATH.include?(lib_path)
-require "spec"
+require 'spec/autorun'
