@@ -5,8 +5,7 @@ module Test
     # This extension of the standard Test::Unit::TestCase makes RSpec
     # available from within, so that you can do things like:
     #
-    # require 'test/unit'
-    # require 'spec'
+    # require 'spec/test/unit'
     #
     # class MyTest < Test::Unit::TestCase
     #   it "should work with Test::Unit assertions" do
@@ -41,33 +40,17 @@ module Test
       before(:each) {setup}
       after(:each) {teardown}
 
-      def initialize(defined_description, options={}, &implementation)
-        @_defined_description = defined_description
-        
-        # TODO - examples fail in rspec-rails if we remove "|| pending_implementation"
-        #      - find a way to fail without it in rspec's code examples
-        @_implementation = implementation || pending_implementation
-
-        @_result = ::Test::Unit::TestResult.new
-        # @method_name is important to set here because it complies with Test::Unit's interface.
+      def initialize(description, &implementation)
+        super
         # Some Test::Unit extensions depend on @method_name being present.
-        @method_name = @_defined_description
-
-        # TODO - this is necessary to run single examples in rspec-rails, but I haven't
-        # found a good way to write a failing example just within rspec core
-        @_backtrace = caller
+        @method_name = description.description
+        @_result = ::Test::Unit::TestResult.new
       end
 
       def run(ignore_this_argument=nil)
         super()
       end
 
-    private
-
-      def pending_implementation
-        error = Spec::Example::NotYetImplementedError.new(caller)
-        lambda { raise(error) }
-      end
     end
   end
 end
