@@ -25,6 +25,7 @@ module Spec
         @stubs = []
         @proxied_methods = []
         @options = options ? DEFAULT_OPTIONS.dup.merge(options) : DEFAULT_OPTIONS
+        @already_proxied_respond_to = false
       end
 
       def null_object?
@@ -55,11 +56,22 @@ module Spec
         @expectations.last
       end
 
-      def add_stub(expected_from, sym, opts={})
+      def add_stub(expected_from, sym, opts={}, &implementation)
         __add sym
-        @stubs.unshift MessageExpectation.new(@error_generator, @expectation_ordering, expected_from, sym, nil, :any, opts)
+        @stubs.unshift MessageExpectation.new(@error_generator, @expectation_ordering, expected_from, sym, nil, :any, opts, &implementation)
         @stubs.first
       end
+
+      def remove_stub(message)
+        message = message.to_sym
+        
+        if stub_to_remove = @stubs.detect { |s| s.matches_name?(message) }
+          reset_proxied_method(message)
+          @stubs.delete(stub_to_remove)
+        else
+          raise MockExpectationError, "The method `#{message}` was not stubbed or was already unstubbed"
+        end
+      end
       
       def verify #:nodoc:
         verify_expectations
@@ -82,6 +94,10 @@ module Spec
       def has_negative_expectation?(sym)
         @expectations.detect {|expectation| expectation.negative_expectation_for?(sym)}
       end
+      
+      def record_message_received(sym, args, block)
+        @messages_received << [sym, args, block]
+      end
 
       def message_received(sym, *args, &block)
         expectation = find_matching_expectation(sym, *args)
@@ -91,9 +107,9 @@ module Spec
           if expectation = find_almost_matching_expectation(sym, *args)
             expectation.advise(args, block) unless expectation.expected_messages_received?
           end
-          stub.invoke(args, block)
+          stub.invoke(*args, &block)
         elsif expectation
-          expectation.invoke(args, block)
+          expectation.invoke(*args, &block)
         elsif expectation = find_almost_matching_expectation(sym, *args)
           expectation.advise(args, block) if null_object? unless expectation.expected_messages_received?
           raise_unexpected_message_args_error(expectation, *args) unless (has_negative_expectation?(sym) or null_object?)
@@ -110,6 +126,10 @@ module Spec
         @error_generator.raise_unexpected_message_error sym, *args
       end
       
+      def find_matching_method_stub(sym, *args)
+        @stubs.find {|stub| stub.matches(sym, args)}
+      end
+      
     private
 
       def __add(sym)
@@ -118,29 +138,28 @@ module Spec
       end
       
       def warn_if_nil_class(sym)
-        if proxy_for_nil_class? && @@warn_about_expectations_on_nil          
+        if proxy_for_nil_class? & @@warn_about_expectations_on_nil          
           Kernel.warn("An expectation of :#{sym} was set on nil. Called from #{caller[2]}. Use allow_message_expectations_on_nil to disable warnings.")
         end
       end
       
       def define_expected_method(sym)
-        visibility_string = "#{visibility(sym)} :#{sym}"
         unless @proxied_methods.include?(sym)
+          visibility_string = "#{visibility(sym)} :#{sym}"
           if target_responds_to?(sym)
             munged_sym = munge(sym)
             target_metaclass.instance_eval do
-              alias_method munged_sym, sym if method_defined?(sym.to_s)
+              alias_method munged_sym, sym if method_defined?(sym)
             end
             @proxied_methods << sym
           end
+          target_metaclass.class_eval(<<-EOF, __FILE__, __LINE__)
+            def #{sym}(*args, &block)
+              __mock_proxy.message_received :#{sym}, *args, &block
+            end
+            #{visibility_string}
+          EOF
         end
-
-        target_metaclass.class_eval(<<-EOF, __FILE__, __LINE__)
-          def #{sym}(*args, &block)
-            __mock_proxy.message_received :#{sym}, *args, &block
-          end
-          #{visibility_string}
-        EOF
       end
 
       def target_responds_to?(sym)
@@ -162,7 +181,7 @@ module Spec
       end
 
       def munge(sym)
-        "proxied_by_rspec__#{sym.to_s}".to_sym
+        "proxied_by_rspec__#{sym}"
       end
 
       def clear_expectations
@@ -189,14 +208,17 @@ module Spec
 
       def reset_proxied_methods
         @proxied_methods.each do |sym|
-          munged_sym = munge(sym)
-          target_metaclass.instance_eval do
-            if method_defined?(munged_sym.to_s)
-              alias_method sym, munged_sym
-              undef_method munged_sym
-            else
-              remove_method sym
-            end
+          reset_proxied_method(sym)
+        end
+      end
+
+      def reset_proxied_method(sym)
+        munged_sym = munge(sym)
+        target_metaclass.instance_eval do
+          remove_method sym
+          if method_defined?(munged_sym)
+            alias_method sym, munged_sym
+            remove_method munged_sym
           end
         end
       end
@@ -210,6 +232,7 @@ module Spec
       end
 
       def find_matching_expectation(sym, *args)
+        @expectations.find {|expectation| expectation.matches(sym, args) && !expectation.called_max_times?} || 
         @expectations.find {|expectation| expectation.matches(sym, args)}
       end
 
@@ -217,10 +240,6 @@ module Spec
         @expectations.find {|expectation| expectation.matches_name_but_not_args(sym, args)}
       end
 
-      def find_matching_method_stub(sym, *args)
-        @stubs.find {|stub| stub.matches(sym, args)}
-      end
-
     end
   end
 end
