@@ -48,7 +48,6 @@ module Spec
     # This task can also be used to run existing Test::Unit tests and get RSpec
     # output, for example like this:
     #
-    #   require 'rubygems'
     #   require 'spec/rake/spectask'
     #   Spec::Rake::SpecTask.new do |t|
     #     t.ruby_opts = ['-rtest/unit']
@@ -119,6 +118,9 @@ module Spec
       # Use verbose output. If this is set to true, the task will print
       # the executed spec command to stdout. Defaults to false.
       attr_accessor :verbose
+      
+      # Explicitly define the path to the ruby binary, or its proxy (e.g. multiruby)
+      attr_accessor :ruby_cmd
 
       # Defines a new task, using the name +name+.
       def initialize(name=:spec)
@@ -153,7 +155,7 @@ module Spec
               # ruby [ruby_opts] -Ilib -S rcov [rcov_opts] bin/spec -- examples [spec_opts]
               # or
               # ruby [ruby_opts] -Ilib bin/spec examples [spec_opts]
-              cmd_parts = [RUBY]
+              cmd_parts = [ruby_cmd || RUBY]
               cmd_parts += ruby_opts
               cmd_parts << %[-I"#{lib_path}"]
               cmd_parts << "-S rcov" if rcov
@@ -193,8 +195,11 @@ module Spec
       end
 
       def rcov_option_list # :nodoc:
-        return "" unless rcov
-        ENV['RCOV_OPTS'] || rcov_opts.join(" ") || ""
+        if rcov
+          ENV['RCOV_OPTS'] || rcov_opts.join(" ") || ""
+        else
+          ""
+        end
       end
 
       def spec_option_list # :nodoc:
